function generate_initial_state(K, tinit, nn)
% Generate initial states of {n,e} from the stationary distribution
%   at a fixed set of population sizes (for plotting)
% Algorithm: Run simulation until the required population size is acquired
% K : carrying capacity
% tinit: time interval for initialization
% nn: vector of required population sizes

rand('state',fix(sum(1000*clock)))
randn('state',fix(sum(2000*clock)))

for n = nn
	disp(n)
	pars = getPars(K,tinit);
	[sim,pop,env,t_now] = sim_single_clone(pars);
	while pop.ntot ~= n
		pars.tmax = pars.tmax + 1e2;
		[sim,pop,env,t_now] = sim_single_clone(pars, t_now, pop, env, n);
		figure_quiet(1), clf, plot(sim.ntot(sim.ntot>0),'.-'), drawnow
	end
	epsilon = getEnvironmentAt(env,t_now);
	env = startEnvironment(pars, epsilon); % restart the environment at its current state to get the time start at 0
	startPop = pop;
    if K>=1000 || K==100
        file_name = sprintf('IS_K%d_n%d.mat', log10(K), n);
    else
        file_name = sprintf('IS_K%d_n%d.mat', K, n);
    end
	save(file_name, 'env', 'startPop', 'sim' )
	drawnow
end
