function [sim,pop,env,t_now] = sim_single_clone(pars,t_now,pop,env, break_n, dt)
% Continuous time birth-and-death model, discrete time approach

demographic_stochasticity = true;

if ~exist('t_now','var') || isempty(t_now)
    t_now = 0;
end
if ~exist('break_n', 'var')
    break_n = 0;
end
if ~exist('pop','var') || isempty(pop)
    pop.n = round(pars.K);
    pop.ntot = pop.n;
    pop.x = pars.xinit;
end
if ~exist('dt','var')
	dt = 0.01;
end

d0 = pars.d0;
r = pars.r;
K = pars.K;
x = pop.x;
%[b,d] = birth_death(pop.x,pop.n,pars,0);
b = d0 + r;
d = d0 + r;

%Calculate appropriate time step:
steps_per_sample = ceil(pars.sampling_interval/dt);
dt = pars.sampling_interval/steps_per_sample;
tt = t_now + (0:pars.sampling_interval:pars.tmax);
sim.dt = dt;
sim.steps_per_sample = steps_per_sample;
sim.tt = tt;

if ~exist('env','var') || isempty(env)
    env = startEnvironment(pars,[],dt);
end

epsilon = getEnvironmentAt(env,t_now);
envT1 = env.T1;
eps0 = env.v0 + (env.v1-env.v0)*(-env.T0)/env.dt;
epsC = (env.v1-env.v0)/env.dt;

sim.ntot = zeros(size(sim.tt),'uint32');
sim.ntot(1) = pop.ntot;
sim.epsilon = zeros(size(sim.tt),'single');
sim.epsilon(1) = epsilon;
%sim.cumF = zeros(size(sim.tt),'single');
%cumF = 0;

next_drawnow = 0;
for ti = 2 : length(sim.tt)
    pop_n = pop.n;
    t0 = tt(ti-1) - dt;
    for step = 1:steps_per_sample
        t_now = t0 + step*dt;
        % Update environment:
        if t_now > envT1
            [epsilon,env] = getEnvironmentAt(env,t_now);
            envT1 = env.T1;
            eps0 = env.v0 + (env.v1-env.v0)*(-env.T0)/env.dt;
            epsC = (env.v1-env.v0)/env.dt;
        else
            epsilon = eps0 + epsC*t_now; % Interpolated approximation on short time scales
        end
        
        b = max(0, d0 + r + epsilon);
        d = d0 + r*(pop_n/K)^x;
        
        B = b*pop_n;
        D = d*pop_n;
        if demographic_stochasticity
            %births = poissrndApprSingle(B*dt);
            births = 0;
            if B>0
                lambda = B*dt;
                if lambda>160
                    births = max(0, round(lambda + sqrt(lambda)*randn));
                else
                    emL = exp(-lambda);
                    P=rand;
                    while P>emL
                        P = P*rand;
                        births = births+1;
                    end
                end
            end
            %deaths = poissrndApprSingle(D*dt);
            lambda = D*dt;
            if lambda>160
                deaths = max(0, round(lambda + sqrt(lambda)*randn));
            else
                deaths = 0;
                emL = exp(-lambda);
                P=rand;
                while P>emL
                    P = P*rand;
                    deaths = deaths+1;
                end
            end
            
            pop_n = pop_n + births - deaths;
        else
            pop_n = pop_n + round((B-D)*dt);
        end
        if pop_n<=0
            %disp('extinction'), drawnow
            error('extinction!')
        end
        if pop_n == break_n
            pop.n = pop_n;
            pop.ntot = pop.n;
            t_now = t_now + dt;
            [epsilon,env] = getEnvironmentAt(env,t_now); %#ok<ASGLU>
            return
        end
    end % for step
    pop.n = pop_n;
    pop.ntot = pop.n;
    
    % Get correct sampling environment:
    epsilon = env.v0 + (env.v1-env.v0)*(t_now-env.T0 + dt)/env.dt;
    % 	[epsilon,env] = model.getEnvironmentAt(env,sim.tt(ti));
    % 	envT1 = env.T1;
    % Sampling:
    sim.ntot(ti) = pop.ntot;
    sim.epsilon(ti) = epsilon;
    
    %disp([t_now pop.ntot])
    if t_now>next_drawnow
        drawnow
        next_drawnow = t_now+1;
    end
end
t_now = sim.tt(end);
sim.pop = pop;
sim.env = env;

